aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java
diff options
context:
space:
mode:
authorGravatar plf <plf@google.com>2018-02-21 03:23:11 -0800
committerGravatar Copybara-Service <copybara-piper@google.com>2018-02-21 03:25:17 -0800
commit840b3e434866f002421c059226047c524f0dd997 (patch)
treeb8fbd041906c4d0c724ec1874c4c3cbaee98669f /src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java
parent404a670678503db2f9a3baaf89399d687d00a2c7 (diff)
C++: Renames CppCompilationContext to CcCompilationInfo
This is in preparation for migrating to the new way of specifying providers as described in[] RELNOTES:none PiperOrigin-RevId: 186436462
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java b/src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java
index 614369fb91..4dce64b0fe 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/cpp/CppSemantics.java
@@ -30,13 +30,13 @@ public interface CppSemantics {
void finalizeCompileActionBuilder(RuleContext ruleContext, CppCompileActionBuilder actionBuilder);
/**
* Called before {@link CppCompilationContext}s are finalized.
*
- * <p>Gives the semantics implementation the opportunity to change what the C++ rule propagates
- * to dependent rules.
+ * <p>Gives the semantics implementation the opportunity to change what the C++ rule propagates to
+ * dependent rules.
*/
- void setupCompilationContext(
- RuleContext ruleContext, CppCompilationContext.Builder contextBuilder);
+ void setupCcCompilationInfo(
+ RuleContext ruleContext, CcCompilationInfo.Builder ccCompilationInfoBuilder);
/**
* Returns the set of includes which are not mandatory and may be pruned by include processing.
@@ -30,13 +30,13 @@ public interface CppSemantics {
void finalizeCompileActionBuilder(RuleContext ruleContext, CppCompileActionBuilder actionBuilder);
/**
- * Called before {@link CppCompilationContext}s are finalized.
+ * Called before {@link CcCompilationInfo}s are finalized.
*